"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.rule = exports.name = void 0;
const create_rule_1 = require("../utils/create-rule");
const is_helpers_1 = require("../utils/is-helpers");
const USE_MUTATION = 'useMutation';
const MUTATION_KEY = 'mutationKey';
exports.name = 'mutation-key';
exports.rule = (0, create_rule_1.createRule)({
    name: exports.name,
    meta: {
        type: 'problem',
        docs: {
            description: 'Enforce mutationKey to be present in useMutation options',
            recommended: 'error',
        },
        messages: {
            missingMutationKey: `Property mutationKey is required but missing`,
            falsyMutationKey: `Property mutationKey cannot be empty`,
        },
        schema: [],
    },
    defaultOptions: [],
    create(context, _, helpers) {
        return {
            CallExpression(node) {
                const isUseMutation = node.callee.type === 'Identifier' &&
                    node.callee.name === USE_MUTATION &&
                    helpers.isReactQueryImport(node.callee);
                if (!isUseMutation) {
                    return;
                }
                const mutationFnArgument = node.arguments[0];
                if (!mutationFnArgument) {
                    return;
                }
                const optionsArgument = node.arguments[1];
                if (!optionsArgument) {
                    context.report({
                        node,
                        messageId: 'missingMutationKey',
                    });
                    return;
                }
                const hasOptionsArgument = optionsArgument.type === 'ObjectExpression';
                if (!hasOptionsArgument) {
                    return;
                }
                const mutationKeyProperty = optionsArgument.properties.find((property) => {
                    return (property.type === 'Property' &&
                        property.key.type === 'Identifier' &&
                        property.key.name === MUTATION_KEY);
                });
                if (!mutationKeyProperty) {
                    context.report({
                        node,
                        messageId: 'missingMutationKey',
                    });
                    return;
                }
                if (mutationKeyProperty.type === 'Property' &&
                    ((0, is_helpers_1.isPropertyValueNull)(mutationKeyProperty) ||
                        (0, is_helpers_1.isPropertyValueUndefined)(mutationKeyProperty))) {
                    context.report({
                        node: mutationKeyProperty,
                        messageId: 'falsyMutationKey',
                    });
                }
            },
        };
    },
});
